#### v.0.2.1 (2025-07-24)
- Added Support For Microsoft SQL Server Databases

### v0.2.0 (2025-07-01)
- The Studio Interface: Now use Zaturn with an inbuilt UI, with your own LLM API.
- Refactored MCP Code.
- Removed `show_query_result` tool. Query results will now be returned directly.

#### v0.1.7 (2025-05-06)
- Ensured Read-Only For SQLite and MySQL

#### v0.1.6 (2025-04-25)
- Added Clickhouse Support

#### v0.1.5 (2025-04-22)
- Changed plotting library to plotly instead of seaborn
- Fixed labeling issues in visualizations
